@@ -36,3 +36,23 @@ class UseTestcaseStatementError(InterpreterError):
 class ConnectDeviceStatementError(InterpreterError):
     """Use to capture error for interpreting connect device statement"""
 
+
+class DisconnectDeviceStatementError(InterpreterError):
+    """Use to capture error for interpreting disconnect device statement"""
+
+
+class ReleaseDeviceStatementError(InterpreterError):
+    """Use to capture error for interpreting release device statement"""
+
+
+class ReleaseResourceStatementError(InterpreterError):
+    """Use to capture error for interpreting release resource statement"""
+
+
+class WaitForStatementError(InterpreterError):
+    """Use to capture error for interpreting wait for statement"""
+
+
+class PerformerStatementError(InterpreterError):
+    """Use to capture error for performer statement"""
+
